***************************
Principle 1: Representation
***************************

.. toctree::

   examples/single_neuron
   examples/two_neurons
   examples/many_neurons
   examples/2d_representation
   examples/combining
   examples/addition
